@@ -2,6 +2,8 @@
     m = length(x), control = ani.control(), ...) {
     extraArgs = list(...)
     if (length(extraArgs)) {
+        if ("interval" %in% names(extraArgs)) 
+            ani.control(...)
         controlargs = names(formals(ani.control))
         idx = match(names(extraArgs), controlargs, nomatch = 0)
         if (any(idx == 0)) 
