@@ -4,6 +4,8 @@
     interval = 0.05), ...) {
     extraArgs = list(...)
     if (length(extraArgs)) {
+        if ("interval" %in% names(extraArgs)) 
+            ani.control(...)
         controlargs = names(formals(ani.control))
         idx = match(names(extraArgs), controlargs, nomatch = 0)
         if (any(idx == 0)) 
