@@ -2,6 +2,8 @@ cv.ani <- function(x = runif(150), k = 10, control = ani.control(interval = 2,
     nmax = 50), ...) {
     extraArgs = list(...)
     if (length(extraArgs)) {
+        if ("interval" %in% names(extraArgs)) 
+            ani.control(...)
         controlargs = names(formals(ani.control))
         idx = match(names(extraArgs), controlargs, nomatch = 0)
         if (any(idx == 0)) 
